@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 # ABSTRACT: composable units of assertion
-$Test::Routine::VERSION = '0.027';
+$Test::Routine::VERSION = '0.028';
 #pod =head1 SYNOPSIS
 #pod
 #pod   # mytest.t
@@ -328,7 +328,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -533,13 +533,24 @@ When you run it:
       # No tests run!
   not ok 1 - No tests run for subtest "invalid"
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex White Dagfinn Ilmari Mannsåker gregor herrmann Jesse Luehrs Yanick Champoux
+=for stopwords Alex White Dagfinn Ilmari Mannsåker gregor herrmann Jesse Luehrs Ricardo Signes Yanick Champoux
 
 =over 4
 
@@ -561,6 +572,10 @@ Jesse Luehrs <doy@tozt.net>
 
 =item *
 
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
 Yanick Champoux <yanick@babyl.dyndns.org>
 
 =back
