@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine::Manual::Demo;
 # ABSTRACT: a walkthrough, in code, of Test::Routine
-$Test::Routine::Manual::Demo::VERSION = '0.025';
+$Test::Routine::Manual::Demo::VERSION = '0.028';
 #pod =head1 The Demo
 #pod
 #pod =head2 t/demo/01-demo.t
@@ -378,7 +378,7 @@ $Test::Routine::Manual::Demo::VERSION = '0.025';
 #pod   
 #pod     has id => (
 #pod       is      => 'ro',
-#pod       default => sub { 
+#pod       default => sub {
 #pod         my ($self) = @_;
 #pod         return Scalar::Util::refaddr($self);
 #pod       },
@@ -447,7 +447,18 @@ Test::Routine::Manual::Demo - a walkthrough, in code, of Test::Routine
 
 =head1 VERSION
 
-version 0.025
+version 0.028
+
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 The Demo
 
@@ -820,7 +831,7 @@ version 0.025
   
     has id => (
       is      => 'ro',
-      default => sub { 
+      default => sub {
         my ($self) = @_;
         return Scalar::Util::refaddr($self);
       },
@@ -872,7 +883,7 @@ version 0.025
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
