@@ -1,6 +1,6 @@
 package Test::Routine::Runner;
 # ABSTRACT: tools for running Test::Routine tests
-$Test::Routine::Runner::VERSION = '0.024';
+$Test::Routine::Runner::VERSION = '0.028';
 use Moose;
 
 #pod =head1 OVERVIEW
@@ -53,13 +53,6 @@ coerce 'Test::Routine::_InstanceBuilder',
   from 'Test::Routine::_Instance',
   via  { my $instance = $_; sub { $instance } };
 
-has test_instance => (
-  is   => 'ro',
-  does => 'Test::Routine::Common',
-  init_arg   => undef,
-  lazy_build => 1,
-);
-
 has _instance_builder => (
   is  => 'ro',
   isa => 'Test::Routine::_InstanceBuilder',
@@ -68,7 +61,7 @@ has _instance_builder => (
   init_arg => 'instance_from',
   required => 1,
   handles  => {
-    '_build_test_instance' => 'execute_method',
+    'build_test_instance' => 'execute_method',
   },
 );
 
@@ -78,19 +71,13 @@ has description => (
   required => 1,
 );
 
-has fresh_instance => (
-  is  => 'ro',
-  isa => 'Bool',
-  default => 0,
-);
-
 sub run {
   my ($self) = @_;
 
-  my $thing = $self->test_instance;
+  my $test_instance = $self->build_test_instance;
 
   my @tests = grep { Moose::Util::does_role($_, 'Test::Routine::Test::Role') }
-              $thing->meta->get_all_methods;
+              $test_instance->meta->get_all_methods;
 
   my $re = $ENV{TEST_METHOD};
   if (defined $re and length $re) {
@@ -108,9 +95,15 @@ sub run {
   } @tests;
 
   Test2::API::run_subtest($self->description, sub {
-    for my $test (@ordered_tests) {
-      $self->test_instance->run_test( $test );
-      $self->clear_test_instance if $self->fresh_instance;
+    TEST: for my $test (@ordered_tests) {
+      my $ctx = Test2::API::context;
+      if (my $reason = $test->skip_reason($test_instance)) {
+        $ctx->skip($test->name, $reason);
+      } else {
+        $test_instance->run_test( $test );
+      }
+
+      $ctx->release;
     }
   });
 }
@@ -129,7 +122,7 @@ Test::Routine::Runner - tools for running Test::Routine tests
 
 =head1 VERSION
 
-version 0.024
+version 0.028
 
 =head1 OVERVIEW
 
@@ -140,9 +133,20 @@ running tests, described in L<Test::Routine|Test::Routine/Running Tests>, are
 more stable.  Please use those instead, unless you are willing to deal with
 interface breakage.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
