@@ -1,6 +1,6 @@
 package Test::Routine::Test;
 # ABSTRACT: a test method in a Test::Routine role
-$Test::Routine::Test::VERSION = '0.025';
+$Test::Routine::Test::VERSION = '0.028';
 use Moose;
 extends 'Moose::Meta::Method';
 
@@ -28,7 +28,7 @@ Test::Routine::Test - a test method in a Test::Routine role
 
 =head1 VERSION
 
-version 0.025
+version 0.028
 
 =head1 OVERVIEW
 
@@ -36,9 +36,20 @@ Test::Routine::Test is a very simple subclass of L<Moose::Meta::Method>, used
 primarily to identify which methods in a class are tests.  It also has
 attributes used for labeling and ordering test runs.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
